@@ -1,5 +1,5 @@
 plotpdiff <- function(x){
-  if (!(class(x) == "fit.piartsm"))
+  if (!inherits(x,"fit.piartsm"))
     stop("\n Object is not of class 'fit.piartsm'.\n")
 
   opar <- par(las=1)
@@ -7,7 +7,5 @@ plotpdiff <- function(x){
   plot(x@pdiff.data, main="Periodically differenced data", ylab="", xlab="")
   bbplot(x@pdiff.data)
   monthplot(x@pdiff.data, ylab="")
-  ##acf(x@pdiff.data, main="Autocorrelations", ylab="", na.action=na.pass)
-  ##pacf(x@pdiff.data, main="Partial autocorrelations", ylab="", na.action=na.pass)
   par(opar)
 }
